# Changes

## 2022.7.24

* Bumped dependecies for development and test
* Moved from jekyll to mkdocs
* Moved documentation to https://codes.dilettant.life/docs/couscous
* Moved tracker to https://todo.sr.ht/~sthagen/couscous
* Moved normative source repo to https://git.sr.ht/~sthagen/couscous
* Added test coverage link to documentation and coverage to https://codes.dilettant.life/coverage/couscous

## 2021.3.2 (0.0.1)

* First release on PyPI.
